/*
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

#include <memory>

#include <folly/python/AsyncioExecutor.h>

namespace folly {
namespace python {
namespace test {

class TestAsyncioExecutor
    : public DroppableAsyncioExecutor<TestAsyncioExecutor> {
 public:
  void add(Func) override {}
  void drive() noexcept override {}
};

inline TestAsyncioExecutor::PtrType makeTestAsyncioExecutor() {
  return TestAsyncioExecutor::create();
}

} // namespace test
} // namespace python
} // namespace folly
